%global pyname certbot-nginx

%if 0%{?fedora}
%bcond_without python3
%else
%bcond_with python3
%endif

%if 0%{?fedora} && 0%{?fedora} >= 30
%bcond_with python2
%else
%bcond_without python2
%endif

Name:       python-%{pyname}
Version:    0.38.0
Release:    1%{?dist}
Summary:    The nginx plugin for certbot

License:    ASL 2.0
URL:        https://pypi.python.org/pypi/certbot-nginx
Source0:    https://files.pythonhosted.org/packages/source/c/%{pyname}/%{pyname}-%{version}.tar.gz

BuildArch:      noarch

%if %{with python2}
BuildRequires: python2-devel
%endif

%if %{with python3}
BuildRequires:  python3-devel
%endif

%if %{with python2}
#For running tests
BuildRequires: python2-acme >= 0.29.0
BuildRequires: python2-certbot >= 0.35.0
%if 0%{?rhel}
# EL7 has unversioned names for these packages
BuildRequires: pyparsing
BuildRequires: pytest
%else
BuildRequires: python2-pyparsing
BuildRequires: python2-pytest
%endif
%endif

%if %{with python3}
BuildRequires: python3-acme >= 0.29.0
BuildRequires: python3-certbot >= 0.35.0
BuildRequires: python3-pyparsing
BuildRequires: python3-pytest
%endif

%description
Plugin for certbot that allows for automatic configuration of ngnix

%if %{with python2}
%package -n python2-%{pyname}
# Provide the name users expect as a certbot plugin
%if ( 0%{?rhel} && 0%{?rhel} <= 7 ) || ( 0%{?fedora} && 0%{?fedora} <= 25 )
Provides:      %{pyname} = %{version}-%{release}
%endif
# Although a plugin for the certbot command it's technically
# an extension to the certbot python libraries
Requires:      python2-acme >= 0.29.0
Requires:      python2-certbot >= 0.35.0
%if 0%{?rhel}
Requires: pyparsing
%else
Requires: python2-pyparsing
%endif
%if 0%{?fedora}
#Recommend the CLI as that will be the interface most use
Recommends:    certbot >= 0.35.0
%else
Requires:      certbot >= 0.35.0
%endif
Summary:     The nginx plugin for certbot
%{?python_provide:%python_provide python2-%{pyname}}

%description -n python2-%{pyname}
Plugin for certbot that allows for automatic configuration of nginx
%endif

%if %{with python3}
%package -n python3-%{pyname}
# Provide the name users expect as a certbot plugin
%if 0%{?fedora} >= 26
Provides:      %{pyname} = %{version}-%{release}
%endif
# Although a plugin for the certbot command it's technically
# an extension to the certbot python libraries
Requires:      python3-acme >= 0.29.0
Requires:      python3-certbot >= 0.35.0
Requires:      python3-pyparsing
%if 0%{?fedora}
#Recommend the CLI as that will be the interface most use
Recommends:    certbot >= 0.35.0
%else
Requires:      certbot >= 0.35.0
%endif
Summary:     The nginx plugin for certbot
%{?python_provide:%python_provide python3-%{pyname}}

%description -n python3-%{pyname}
Plugin for certbot that allows for automatic configuration of nginx
%endif

%prep
%autosetup -p1 -n %{pyname}-%{version}

%build
%if %{with python2}
%{py2_build}
%endif
%if %{with python3}
%py3_build
%endif

%check
%if %{with python2}
(cd build/lib && %{__python2} ../../setup.py test)
%endif
%if %{with python3}
%{__python3} setup.py test
%endif


%install
%if %{with python2}
%{py2_install}
%endif
%if %{with python3}
%py3_install
%endif

%if %{with python2}
%files -n python2-%{pyname}
%license LICENSE.txt
%doc README.rst
%{python2_sitelib}/certbot_nginx
%exclude %{python2_sitelib}/certbot_nginx/tests
%{python2_sitelib}/certbot_nginx-%{version}*.egg-info
%endif

%if %{with python3}
%files -n python3-%{pyname}
%license LICENSE.txt
%doc README.rst
%{python3_sitelib}/certbot_nginx
%exclude %{python3_sitelib}/certbot_nginx/tests
%{python3_sitelib}/certbot_nginx-%{version}*.egg-info
%endif

%changelog
* Tue Sep 10 2019 Eli Young <elyscape@gmail.com> - 0.38.0-1
- Update to 0.38.0 (#1748627)

* Mon Aug 26 2019 Eli Young <elyscape@gmail.com> - 0.37.2-1
- Update to 0.37.2 (#1742593)

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 0.36.0-3
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.36.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Jul 19 2019 Eli Young <elyscape@gmail.com> - 0.36.0-1
- Update to 0.36.0

* Fri Jun 21 2019 Eli Young <elyscape@gmail.com> - 0.35.1-1
- Update to 0.35.1 (#1717693)

* Tue May 28 2019 Eli Young <elyscape@gmail.com> - 0.34.2-1
- Update to 0.34.2 (#1686200)

* Fri Feb 08 2019 Eli Young <elyscape@gmail.com> - 0.31.0-1
- Update to 0.31.0 (#1673775)

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.30.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Jan 28 2019 Eli Young <elyscape@gmail.com> - 0.30.2-1
- Update to 0.30.2 (#1669329)

* Tue Dec 11 2018 Eli Young <elyscape@gmail.com> - 0.29.1-1
- Update to 0.29.1
- Remove Python 2 package in Fedora 30+ (#1654016)

* Wed Nov 14 2018 Eli Young <elyscape@gmail.com> - 0.28.0-1
- Update to 0.28.0

* Mon Sep 10 2018 Eli Young <elyscape@gmail.com> - 0.27.1-1
- Update to 0.27.1 (#1627585)

* Tue Jul 17 2018 Eli Young <elyscape@gmail.com> - 0.26.1-1
- Update to 0.26.1 (#1600304)

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.25.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 0.25.1-2
- Rebuilt for Python 3.7

* Wed Jun 13 2018 Eli Young <elyscape@gmail.com> - 0.25.1-1
- Update to 0.25.1 (#1591043)

* Tue Jun 12 2018 Eli Young <elyscape@gmail.com> - 0.25.0-2
- Add requirement on python-acme >= 0.25.0 (upstream #6096)

* Thu Jun 07 2018 Eli Young <elyscape@gmail.com> - 0.25.0-1
- Update to 0.25.0 (#1588231)

* Wed May 02 2018 Eli Young <elyscape@gmail.com> - 0.24.0-1
- Update to 0.24.0 (#1574150)

* Thu Apr 05 2018 Eli Young <elyscape@gmail.com> - 0.23.0-1
- Update to 0.23.0 (#1563911)

* Tue Mar 20 2018 Eli Young <elyscape@gmail.com> - 0.22.2-1
- Update to 0.22.2 (#1558283)

* Sat Mar 10 2018 Eli Young <elyscape@gmail.com> - 0.22.0-1
- Update to 0.22.0 (#1552956)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.21.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Feb 02 2018 Eli Young <elyscape@gmail.com> - 0.21.1-1
- Update to 0.21.1 (#1535998)

* Wed Dec 20 2017 Eli Young <elyscape@gmail.com> - 0.20.0-1
- Update to 0.20.0

* Fri Oct 06 2017 Eli Young <elyscape@gmail.com> - 0.19.0-1
- Update to 0.19.0 (bz#1499370)

* Fri Oct 06 2017 Eli Young <elyscape@gmail.com> - 0.18.2-2
- Fix provides (bz#1497315)

* Fri Sep 22 2017 Nick Bebout <nb@fedoraproject.org> - 0.18.2-1
- Update to 0.18.2

* Mon Sep 11 2017 Nick Bebout <nb@fedoraproject.org> - 0.18.1-1
- Update to 0.18.1

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.14.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed May 17 2017 James Hogarth <james.hogarth@gmail.com> - 0.14.1-1
- Update to 0.14.1

* Fri May 12 2017 James Hogarth <james.hogarth@gmail.com> - 0.13.0-1
- Update to 0.14.0
- Remove the tests directory from binary rpm

* Fri Apr 21 2017 James Hogarth <james.hogarth@gmail.com> - 0.13.0-1
- Initial packaging of the plugin
